"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const React = __importStar(require("react"));
const antd_1 = require("antd");
const time_1 = require("../lib/time");
const SECOND = 1000;
const MINUTE = 60 * SECOND;
const HOUR = 60 * MINUTE;
const DAY = 24 * HOUR;
const CLOCK_INTERVAL_SECOND = SECOND / 4;
const CLOCK_INTERVAL_MINUTE = MINUTE / 4;
const CLOCK_INTERVAL_HOUR = HOUR / 4;
class NiceElapsedTime extends React.Component {
    constructor(props) {
        super(props);
        this.clockTimer = null;
        this.state = {
            clockTime: Date.now()
        };
    }
    startClock() {
        this.clockTimer = window.setInterval(() => {
            console.log('tick', Date.now());
            this.setState({
                clockTime: Date.now()
            });
        }, CLOCK_INTERVAL_SECOND);
    }
    componentDidMount() {
        if (!this.props.to && this.props.useClock) {
            console.log('starting clock...');
            this.startClock();
        }
    }
    componentWillUnmount() {
        if (this.clockTimer) {
            window.clearInterval(this.clockTimer);
        }
    }
    render() {
        let elapsed;
        if (this.props.to) {
            elapsed = this.props.to - this.props.from;
        }
        else {
            elapsed = this.state.clockTime - this.props.from;
        }
        const [tooltipContent,] = time_1.niceElapsed(elapsed, {});
        if (this.props.showTooltip === false) {
            return React.createElement("span", null, tooltipContent);
        }
        let tooltip;
        if (this.props.tooltipPrefix) {
            tooltip = (React.createElement("span", null,
                this.props.tooltipPrefix,
                React.createElement("span", null, tooltipContent)));
        }
        else {
            tooltip = React.createElement("span", null, tooltipContent);
        }
        const [content, time] = time_1.niceElapsed(elapsed, { precision: this.props.precision });
        return (React.createElement(antd_1.Tooltip, { placement: "bottomRight", title: tooltip }, content));
    }
}
exports.default = NiceElapsedTime;
//# sourceMappingURL=NiceElapsedTime.js.map