import { Action } from 'redux';
import { ThunkDispatch } from 'redux-thunk';
import { AppConfig, AppRuntime, Navigation } from './store';
import { AppError, BaseStoreState } from '../store';
export declare enum ActionType {
    APP_LOAD = "@kbase-ui-lib/app/load",
    APP_LOAD_START = "@kbase-ui-lib/app/load/start",
    APP_LOAD_SUCCESS = "@kbase-ui-lib/app/load/success",
    APP_LOAD_ERROR = "@kbase-ui-lib/app/load/error",
    APP_SEND_MESSAGE = "@kbase-ui-lib/app/send/message",
    APP_SEND_TITLE = "@kbase-ui-lib/app/send/title",
    APP_SET_TITLE = "@kbase-ui-lib/app/set/title",
    APP_NAVIGATE = "@kbase-ui-lib/app/navigate"
}
export interface AppLoadSuccess extends Action {
    type: ActionType.APP_LOAD_SUCCESS;
    config: AppConfig;
    runtime: AppRuntime;
}
export interface AppLoadError extends Action {
    type: ActionType.APP_LOAD_ERROR;
    error: AppError;
}
export interface AppSendTitle extends Action<ActionType.APP_SEND_TITLE> {
    type: ActionType.APP_SEND_TITLE;
    title: string;
}
export interface AppSetTitle extends Action<ActionType.APP_SET_TITLE> {
    type: ActionType.APP_SET_TITLE;
    title: string;
}
export interface AppNavigate extends Action<ActionType.APP_NAVIGATE> {
    type: ActionType.APP_NAVIGATE;
    navigation: Navigation;
}
export declare function loadSuccess(config: AppConfig, runtime: AppRuntime): AppLoadSuccess;
export declare function loadError(error: AppError): AppLoadError;
export declare function sendTitle(title: string): (dispatch: ThunkDispatch<BaseStoreState, void, Action<any>>, getState: () => BaseStoreState) => Promise<void>;
export declare function setTitle(title: string): AppSetTitle;
export declare function navigate(navigation: Navigation): {
    type: ActionType;
    navigation: Navigation;
};
export declare function appStart(): (dispatch: ThunkDispatch<BaseStoreState, void, Action<any>>, getState: () => BaseStoreState) => void;
export interface SendMessage {
    type: ActionType.APP_SEND_MESSAGE;
    messageName: string;
    payload: object;
}
export declare function sendMessage(messageName: string, payload: object): (dispatch: ThunkDispatch<BaseStoreState, void, Action<any>>, getState: () => BaseStoreState) => void;
